@@ -63,13 +63,15 @@ test_that("remove_keys_all works", {
 test_that("remove_keys_if works", {
   output <- df_keyed %>% remove_keys_if(rlang::is_integerish)
   remove_syms <- select_if(keys(df_keyed), rlang::is_integerish) %>%
-    names() %>% rlang::syms()
-  output_ref <- df_keyed %>% remove_keys(!!! remove_syms)
+    names() %>%
+    rlang::syms()
+  output_ref <- df_keyed %>% remove_keys(!!!remove_syms)
 
   expect_identical(output, output_ref)
 
-  expect_silent(df_keyed %>% remove_keys_if(rlang::is_integerish,
-                                            .funs = toupper))
+  expect_silent(
+    df_keyed %>% remove_keys_if(rlang::is_integerish, .funs = toupper)
+  )
 })
 
 
@@ -86,23 +88,25 @@ test_that("remove_keys_at works", {
 
 # restore_keys_all --------------------------------------------------------
 test_that("restore_keys_all works", {
-  output_1 <- df_keyed %>% restore_keys_all(.funs = toupper,
-                                            .remove = FALSE, .unkey = FALSE)
+  output_1 <- df_keyed %>%
+    restore_keys_all(.funs = toupper, .remove = FALSE, .unkey = FALSE)
   keys_restored <- select_all(keys(df_keyed), .funs = toupper)
   output_ref_1 <- df_keyed %>% assign_tbl(keys_restored)
 
   expect_identical(output_1, output_ref_1)
 
-  output_2 <- df_keyed %>% restore_keys_all(.funs = toupper,
-                                            .remove = TRUE, .unkey = FALSE)
-  output_ref_2 <- df_keyed %>% assign_tbl(keys_restored) %>%
+  output_2 <- df_keyed %>%
+    restore_keys_all(.funs = toupper, .remove = TRUE, .unkey = FALSE)
+  output_ref_2 <- df_keyed %>%
+    assign_tbl(keys_restored) %>%
     remove_keys_all(.unkey = FALSE)
 
   expect_identical(output_2, output_ref_2)
 
-  output_3 <- df_keyed %>% restore_keys_all(.funs = toupper,
-                                            .remove = TRUE, .unkey = TRUE)
-  output_ref_3 <- df_keyed %>% assign_tbl(keys_restored) %>%
+  output_3 <- df_keyed %>%
+    restore_keys_all(.funs = toupper, .remove = TRUE, .unkey = TRUE)
+  output_ref_3 <- df_keyed %>%
+    assign_tbl(keys_restored) %>%
     remove_keys_all(.unkey = TRUE)
 
   expect_identical(output_3, output_ref_3)
@@ -112,26 +116,43 @@ test_that("restore_keys_all works", {
 # restore_keys_if ---------------------------------------------------------
 test_that("restore_keys_if works", {
   output_1 <- df_keyed %>%
-    restore_keys_if(rlang::is_integerish, .funs = toupper,
-                    .remove = FALSE, .unkey = FALSE)
-  keys_restored <- select_if(keys(df_keyed), rlang::is_integerish,
-                             .funs = toupper)
+    restore_keys_if(
+      rlang::is_integerish,
+      .funs = toupper,
+      .remove = FALSE,
+      .unkey = FALSE
+    )
+  keys_restored <- select_if(
+    keys(df_keyed),
+    rlang::is_integerish,
+    .funs = toupper
+  )
   output_ref_1 <- df_keyed %>% assign_tbl(keys_restored)
 
   expect_identical(output_1, output_ref_1)
 
   output_2 <- df_keyed %>%
-    restore_keys_if(rlang::is_integerish, .funs = toupper,
-                    .remove = TRUE, .unkey = FALSE)
-  output_ref_2 <- df_keyed %>% assign_tbl(keys_restored) %>%
+    restore_keys_if(
+      rlang::is_integerish,
+      .funs = toupper,
+      .remove = TRUE,
+      .unkey = FALSE
+    )
+  output_ref_2 <- df_keyed %>%
+    assign_tbl(keys_restored) %>%
     remove_keys_if(rlang::is_integerish, .unkey = FALSE)
 
   expect_identical(output_2, output_ref_2)
 
   output_3 <- df_keyed %>%
-    restore_keys_if(rlang::is_integerish, .funs = toupper,
-                    .remove = TRUE, .unkey = TRUE)
-  output_ref_3 <- df_keyed %>% assign_tbl(keys_restored) %>%
+    restore_keys_if(
+      rlang::is_integerish,
+      .funs = toupper,
+      .remove = TRUE,
+      .unkey = TRUE
+    )
+  output_ref_3 <- df_keyed %>%
+    assign_tbl(keys_restored) %>%
     remove_keys_if(rlang::is_integerish, .unkey = TRUE)
 
   expect_identical(output_3, output_ref_3)
@@ -141,26 +162,39 @@ test_that("restore_keys_if works", {
 # restore_keys_at ---------------------------------------------------------
 test_that("restore_keys_at works", {
   output_1 <- df_keyed %>%
-    restore_keys_at(c("vs", "disp"), .funs = toupper,
-                    .remove = FALSE, .unkey = FALSE)
-  keys_restored <- select_at(keys(df_keyed), c("vs", "disp"),
-                             .funs = toupper)
+    restore_keys_at(
+      c("vs", "disp"),
+      .funs = toupper,
+      .remove = FALSE,
+      .unkey = FALSE
+    )
+  keys_restored <- select_at(keys(df_keyed), c("vs", "disp"), .funs = toupper)
   output_ref_1 <- df_keyed %>% assign_tbl(keys_restored)
 
   expect_identical(output_1, output_ref_1)
 
   output_2 <- df_keyed %>%
-    restore_keys_at(c("vs", "disp"), .funs = toupper,
-                    .remove = TRUE, .unkey = FALSE)
-  output_ref_2 <- df_keyed %>% assign_tbl(keys_restored) %>%
+    restore_keys_at(
+      c("vs", "disp"),
+      .funs = toupper,
+      .remove = TRUE,
+      .unkey = FALSE
+    )
+  output_ref_2 <- df_keyed %>%
+    assign_tbl(keys_restored) %>%
     remove_keys_at(c("vs", "disp"), .unkey = FALSE)
 
   expect_identical(output_2, output_ref_2)
 
   output_3 <- df_keyed %>%
-    restore_keys_at(c("vs", "disp"), .funs = toupper,
-                    .remove = TRUE, .unkey = TRUE)
-  output_ref_3 <- df_keyed %>% assign_tbl(keys_restored) %>%
+    restore_keys_at(
+      c("vs", "disp"),
+      .funs = toupper,
+      .remove = TRUE,
+      .unkey = TRUE
+    )
+  output_ref_3 <- df_keyed %>%
+    assign_tbl(keys_restored) %>%
     remove_keys_at(c("vs", "disp"), .unkey = TRUE)
 
   expect_identical(output_3, output_ref_3)
@@ -179,8 +213,10 @@ test_that("rename_keys_all works", {
 # rename_keys_if ----------------------------------------------------------
 test_that("rename_keys_if works", {
   output <- df_keyed %>% rename_keys_if(rlang::is_integerish, toupper)
-  output_ref <- assign_keys(df, rename_if(keys(df_keyed),
-                                          rlang::is_integerish, toupper))
+  output_ref <- assign_keys(
+    df,
+    rename_if(keys(df_keyed), rlang::is_integerish, toupper)
+  )
 
   expect_identical(output, output_ref)
 })
@@ -189,8 +225,10 @@ test_that("rename_keys_if works", {
 # rename_keys_at ----------------------------------------------------------
 test_that("rename_keys_at works", {
   output <- df_keyed %>% rename_keys_at(c("vs", "disp"), toupper)
-  output_ref <- assign_keys(df, rename_at(keys(df_keyed),
-                                          c("vs", "disp"), toupper))
+  output_ref <- assign_keys(
+    df,
+    rename_at(keys(df_keyed), c("vs", "disp"), toupper)
+  )
 
   expect_identical(output, output_ref)
 })
